using System;
using System.Drawing;
using System.Drawing.Printing;

namespace Buffy.Common.Reporting
{
	/// <summary>
	/// Summary description for Box.
	/// </summary>
	public class Box : ReportRow
	{

		private float mWidth;
		private float mX;

		public Brush Brush = Brushes.Black;
		public Brush Background = Brushes.Transparent;
		public float BorderWidth = 1;

		public Box(float x, float width, float height) : base(height)
		{
			this.Width = width;
			this.X = x;
		}

		public float Width
		{
			get
			{
				return (this.mWidth);
			}
			set
			{
				this.mWidth = value;
			}
		}

		public float X
		{
			get
			{
				return (this.mX);
			}
			set
			{
				this.mX = value;
			}
		}

		public override float Print(PrintPageEventArgs ev, float x, float y, Font font)
		{
			x = X + x;

			if (Background != Brushes.Transparent)
			{
				ev.Graphics.FillRectangle(Background, x, y, Width, Height);
			}

			if (BorderWidth > 0)
			{
				Pen p = new Pen(Brush, BorderWidth);
				ev.Graphics.DrawRectangle(p, x, y, Width, Height);
			}

			//base.Print(ev, y, font);

			if (DefaultFont != null)
				font = DefaultFont;
			float maxH = Height; 

			foreach (IReportItem item in Items)
			{
				y += item.Print(ev, x, y, font);
			}

			return Height;
		}
	}
}
