using System;
using System.Drawing;
using System.Drawing.Printing;

namespace ReflectionIT.Common.Reporting
{
	/// <summary>
	/// A ReportGroup is used to group items together. 
	/// 
	/// All items within the group are normally printed on the same line (y-coordinate), 
	/// you can change this behavior by setting the FixedTop property to 'false'. 
	/// 
	/// A ReportGroup can have a BackColor and a BorderPen which only have meaning when 
	/// the Height property is set to a non-zero value
	/// </summary>
	public class ReportGroup : ReportItemBase, IReportItem
	{
		protected ReportItemCollection mItems = new ReportItemCollection();
		private bool mFixedTop = true;

		public ReportGroup() : this(0, 0, 0)
		{
		}

		public ReportGroup(float heigth) : this(0, 0, heigth)
		{
		}

		public ReportGroup(float left, float width, float height) : base(left, width, height)
		{
		}


		/// <summary>
		/// Destuctor
		/// </summary>
		public override void Dispose()
		{
			Items.Dispose();
			base.Dispose();
		}

		public bool FixedTop
		{
			get
			{
				return (this.mFixedTop);
			}
			set
			{
				this.mFixedTop = value;
			}
		}

		/// <summary>
		/// Gets the collection of ReportItems
		/// </summary>
		public ReportItemCollection Items
		{
			get
			{
				return (this.mItems);
			}
		}


		float IReportItem.Print(PrintPageEventArgs ev, float x, float y, Font font)
		{
			if (Font != null)
				font = Font;

			base.Print(ev, x, y, font);

			float h = 0;
			float maxH = this.Heigth; 

			y += Margin.Top;
			x += Margin.Left;

			foreach (IReportItem item in Items)
			{
				h = item.Print(ev, x + Left, y, font);

				if (!FixedTop)
					y += h;

				if (h > maxH)
					maxH = h;
			}

			return maxH;
		}
	}
}
