using System;
using System.Drawing;
using System.Drawing.Printing;
using System.Drawing.Drawing2D;

namespace ReflectionIT.Common.Reporting
{
	/// <summary>
	/// ReportHorizontalLine prints a horizontal line on a Report.
	/// </summary>
	public class ReportHorizontalLine : IReportItem
	{
		public Pen Pen = new Pen(Brushes.Black, 1);
		private float mLeft;
		private float mWidth;
		private float mHeigth;

		/// <summary>
		/// Constructor with a Heigh of 1
		/// </summary>
		/// <param name="left">X-coordinate</param>
		/// <param name="width">Width</param>
		public ReportHorizontalLine(float left, float width) : this(left, width, 1)
		{
		}

		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="left">X-coordinate</param>
		/// <param name="width">Width</param>
		/// <param name="height">Height</param>
		public ReportHorizontalLine(float left, float width, float height)
		{
			this.Left = left;
			this.Width = width;
			this.Heigth = height;
		}

		/// <summary>
		/// Destuctor
		/// </summary>
		public virtual void Dispose()
		{
			Pen.Dispose();

			System.GC.SuppressFinalize(this);
		}

		/// <summary>
		/// Gets or sets the x-coordinate of a ReportItem left edge.
		/// </summary>
		public float Left
		{
			get
			{
				return (this.mLeft);
			}
			set
			{
				this.mLeft = value;
			}
		}

		/// <summary>
		/// Gets or sets the width of the ReportItem.
		/// </summary>
		public float Width
		{
			get
			{
				return (this.mWidth);
			}
			set
			{
				this.mWidth = value;
			}
		}

		/// <summary>
		/// Gets or sets the height of the ReportItem.
		/// </summary>
		public float Heigth
		{
			get
			{
				return (this.mHeigth);
			}
			set
			{
				this.mHeigth = value;
			}
		}

		float IReportItem.Print(PrintPageEventArgs ev, float x, float y, Font font)
		{
			float x1 = Left + x;
			float x2 = x1 + Width;
			
			ev.Graphics.DrawLine(Pen, x1, y, x2, y);

			return Heigth;
		}
	}
}
