using System;
using System.Drawing;
using System.Drawing.Printing;
using System.Drawing.Drawing2D;

namespace ReflectionIT.Common.Reporting
{
	/// <summary>
	/// Summary description for ReportItem.
	/// </summary>
	public abstract class ReportItemBase
	{
		private float mLeft;
		private float mWidth;
		private float mHeigth;
		private Brush mBackColor = Brushes.Transparent;
		public Margins Margin = new Margins(0,0,0,0);
		private Pen mBorderPen = null;
		private Font mFont = null;

		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="left">X-coordinate</param>
		/// <param name="width">Width</param>
		/// <param name="height">Height</param>
		public ReportItemBase(float left, float width, float height)
		{
			this.Left = left;
			this.Width = width;
			this.Heigth = height;
		}

		/// <summary>
		/// Destuctor
		/// </summary>
		public virtual void Dispose()
		{
			if (BorderPen != null)
				BorderPen.Dispose();

			if (Font != null)
				Font.Dispose();
		}

		/// <summary>
		/// Gets or sets the x-coordinate of a ReportItem left edge.
		/// </summary>
		public float Left
		{
			get
			{
				return (this.mLeft);
			}
			set
			{
				this.mLeft = value;
			}
		}

		/// <summary>
		/// Gets or sets the width of the ReportItem.
		/// </summary>
		public float Width
		{
			get
			{
				return (this.mWidth);
			}
			set
			{
				this.mWidth = value;
			}
		}

		/// <summary>
		/// Gets or sets the height of the ReportItem.
		/// </summary>
		public float Heigth
		{
			get
			{
				return (this.mHeigth);
			}
			set
			{
				this.mHeigth = value;
			}
		}

		/// <summary>
		/// Gets or sets the BackColor of the ReportItem.
		/// </summary>
		public Brush BackColor
		{
			get
			{
				return (this.mBackColor);
			}
			set
			{
				this.mBackColor = value;
			}
		}

		/// <summary>
		/// Gets or sets the BorderPen used to draw the Border of the ReportItem.
		/// </summary>
		public Pen BorderPen
		{
			get
			{
				return (this.mBorderPen);
			}
			set
			{
				this.mBorderPen = value;
			}
		}

		/// <summary>
		/// Gets or sets the Font of the ReportItem. If 'null' the reports default font will be used.
		/// </summary>
		public Font Font
		{
			get
			{
				return (this.mFont);
			}
			set
			{
				this.mFont = value;
			}
		}

		protected float Print(PrintPageEventArgs ev, float x, float y, Font font)
		{
			x = Left + x;

			if (BackColor != Brushes.Transparent)
			{
				ev.Graphics.FillRectangle(BackColor, x, y, Width, Heigth);
			}

			if (BorderPen != null)
			{
				ev.Graphics.DrawRectangle(BorderPen, x, y, Width, Heigth);
			}
			
			return Heigth;
		}
	}
}
