using System;
using System.Collections;

namespace ReflectionIT.Common.Reporting
{
	/// <summary>
	/// Collection class of ReportItems
	/// </summary>
	public class ReportItemCollection : IEnumerable, IDisposable
	{
		protected ArrayList mItems = new ArrayList();

		/// <summary>
		/// Destructor, disposes all ReportItems in the collection
		/// </summary>
		public void Dispose()
		{
			foreach (IReportItem item in this)
			{
				item.Dispose();
			}

			System.GC.SuppressFinalize(this);
		}

		/// <summary>
		/// Add a ReportItem to the collection
		/// </summary>
		/// <param name="Item"></param>
		public void Add(IReportItem Item)
		{
			mItems.Add(Item);
		}

		/// <summary>
		/// Returns the number of ReportItems in the collection
		/// </summary>
		public int Count
		{
			get { return mItems.Count; }
		}

		/// <summary>
		/// Indexer
		/// </summary>
		public IReportItem this[int index]
		{
			get { return (IReportItem)mItems[index]; }
		}

		/// <summary>
		/// Returns an enumerator that can iterate through the collection
		/// </summary>
		/// <returns>An IEnumerator for the entire collection.</returns>
		public IEnumerator GetEnumerator()
		{
			return mItems.GetEnumerator();
		}

		/// <summary>
		/// Clear the collection
		/// </summary>
		public void Clear()
		{
			mItems.Clear();
		}
	}
}
